@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2006-2008 David Collett
  * Copyright (C) 2008-2012 K. Henriksson
- * Copyright (C) 2017-2023 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2024 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
  * @author Norbert Schlia (nschlia@oblivion-software.de)
  * @copyright Copyright (C) 2006-2008 David Collett @n
  * Copyright (C) 2008-2013 K. Henriksson @n
- * Copyright (C) 2017-2023 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2024 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #include "transcode.h"
@@ -1874,7 +1874,7 @@ static int selector(const struct dirent * de)
 static int scandir(const char *dirp, std::vector<struct dirent> * _namelist, int (*selector) (const struct dirent *), int (*cmp) (const struct dirent **, const struct dirent **))
 {
     struct dirent **namelist;
-    int count = scandir(dirp, &namelist, selector, cmp);
+    int count = scandir(dirp, &namelist, selector, cmp);    // cppcheck-suppress [nullPointer, ctunullpointer]
 
     _namelist->clear();
 
@@ -1927,6 +1927,7 @@ LPVIRTUALFILE find_original(std::string * filepath)
             remove_filename(&dir);
             origfile = dir;
 
+            // cppcheck-suppress nullPointer
             count = scandir(dir.c_str(), &namelist, selector, nullptr);
             if (count == -1)
             {
@@ -1999,8 +2000,6 @@ LPVIRTUALFILE find_parent(const std::string & origpath)
 static int make_hls_fileset(void * buf, fuse_fill_dir_t filler, const std::string & origpath, LPVIRTUALFILE virtualfile)
 {
     // Generate set of TS segment files and necessary M3U lists
-    std::string master_contents;
-    std::string index_0_av_contents;
 
     if (!virtualfile->get_segment_count())
     {
@@ -2013,6 +2012,9 @@ static int make_hls_fileset(void * buf, fuse_fill_dir_t filler, const std::strin
 
     if (virtualfile->get_segment_count())
     {
+        std::string master_contents;
+        std::string index_0_av_contents;
+
         // Examples...
         //"#EXT-X-STREAM-INF:PROGRAM-ID=1,BANDWIDTH=1250,RESOLUTION=720x406,CODECS= \"avc1.77.30, mp4a.40.2 \",CLOSED-CAPTIONS=NONE\n"
         //"index_0_av.m3u8\n";
